==> regina-normal_5.1.orig.tar.gz: regina-5.1/python/manifold/torusbundle.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include <boost/python.hpp>
#include "algebra/abeliangroup.h"
#include "manifold/torusbundle.h"
#include "../helpers.h"

using namespace boost::python;
using regina::Matrix2;
using regina::TorusBundle;

void addTorusBundle() {
    class_<TorusBundle, bases<regina::Manifold>,
            std::auto_ptr<TorusBundle> >("TorusBundle")
        .def(init<const Matrix2&>())
        .def(init<long, long, long, long>())
        .def(init<const TorusBundle&>())
        .def("monodromy", &TorusBundle::monodromy,
            return_internal_reference<>())
        .def(regina::python::add_eq_operators())
    ;

    implicitly_convertible<std::auto_ptr<TorusBundle>,
        std::auto_ptr<regina::Manifold> >();

    scope().attr("NTorusBundle") = scope().attr("TorusBundle");
}

==> regina-normal_5.95.orig.tar.gz: regina-5.95/python/manifold/torusbundle.cpp <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  Python Interface                                                      *
 *                                                                        *
 *  Copyright (c) 1999-2018, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

#include "../pybind11/pybind11.h"
#include "algebra/abeliangroup.h"
#include "manifold/torusbundle.h"
#include "../helpers.h"

using regina::Matrix2;
using regina::TorusBundle;

void addTorusBundle(pybind11::module_& m) {
    pybind11::class_<TorusBundle, regina::Manifold>(m, "TorusBundle")
        .def(pybind11::init<>())
        .def(pybind11::init<const Matrix2&>())
        .def(pybind11::init<long, long, long, long>())
        .def(pybind11::init<const TorusBundle&>())
        .def("monodromy", &TorusBundle::monodromy,
            pybind11::return_value_policy::reference_internal)
    ;

    m.attr("NTorusBundle") = m.attr("TorusBundle");
}
